@@ -30,7 +30,7 @@ def sort_by_formula_id(raw_datasets):
     return by_formula_id
 
 
-def filter_label(label):
+def filter_label(label, replace_by_similar=True):
     bad_names = ['celsius', 'degree', 'ohm', 'venus', 'mars', 'astrosun',
                  'fullmoon', 'leftmoon', 'female', 'male', 'checked',
                  'diameter', 'sun', 'Bowtie', 'sqrt',
@@ -38,9 +38,9 @@ def filter_label(label):
                  'mathds', 'mathfrak'
                  ]
     if any(label[1:].startswith(bad) for bad in bad_names):
-        if label == '\\dag':
+        if label == '\\dag' and replace_by_similar:
             return '\\dagger'
-        elif label == '\\diameter':
+        elif label == '\\diameter' and replace_by_similar:
             return '\\O'
         return label[1:]
     else:
