@@ -326,8 +326,8 @@ class Aspect_ratio(object):
         assert isinstance(handwritten_data, HandwrittenData.HandwrittenData), \
             "handwritten data is not of type HandwrittenData, but of %r" % \
             type(handwritten_data)
-        width = float(handwritten_data.get_width()+1)
-        height = float(handwritten_data.get_height()+1)
+        width = float(handwritten_data.get_width()+0.01)
+        height = float(handwritten_data.get_height()+0.01)
         return [width/height]
 
 
